summaryrefslogtreecommitdiffstats
path: root/chromium/device/fido/u2f_register_operation_unittest.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/device/fido/u2f_register_operation_unittest.cc')
-rw-r--r--chromium/device/fido/u2f_register_operation_unittest.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/chromium/device/fido/u2f_register_operation_unittest.cc b/chromium/device/fido/u2f_register_operation_unittest.cc
index 567ce6186f4..89eb9a94e36 100644
--- a/chromium/device/fido/u2f_register_operation_unittest.cc
+++ b/chromium/device/fido/u2f_register_operation_unittest.cc
@@ -152,10 +152,10 @@ TEST_F(U2fRegisterOperationTest, TestRegistrationWithExclusionList) {
auto device = std::make_unique<MockFidoDevice>();
EXPECT_CALL(*device, GetId()).WillRepeatedly(::testing::Return("device"));
// DeviceTransact() will be called three times including two check only
// sign-in calls and one registration call. For the first two calls, device
// will invoke MockFidoDevice::WrongData as the authenticator did not create
// the two key handles provided in the exclude list. At the third call,
// MockFidoDevice::NoErrorRegister will be invoked after registration.
::testing::InSequence s;
device->ExpectRequestAndRespondWith(
@@ -163,7 +163,7 @@ TEST_F(U2fRegisterOperationTest, TestRegistrationWithExclusionList) {
test_data::kU2fWrongDataApduResponse);
device->ExpectRequestAndRespondWith(
test_data::kU2fCheckOnlySignCommandApduWithKeyBeta,
- test_data::kU2fWrongDataApduResponse);
+ test_data::kU2fWrongLengthApduResponse);
device->ExpectRequestAndRespondWith(
test_data::kU2fRegisterCommandApdu,
test_data::kApduEncodedNoErrorRegisterResponse);
@@ -152,10 +152,10 @@ TEST_F(U2fRegisterOperationTest, TestRegistrationWithExclusionList) {
auto device = std::make_unique<MockFidoDevice>();
EXPECT_CALL(*device, GetId()).WillRepeatedly(::testing::Return("device"));
- // DeviceTransact() will be called three times including two check only
- // sign-in calls and one registration call. For the first two calls, device
- // will invoke MockFidoDevice::WrongData as the authenticator did not create
- // the two key handles provided in the exclude list. At the third call,
+ // DeviceTransact() will be called three times including two check only sign-
+ // in calls and one registration call. For the first two calls, device will
+ // invoke MockFidoDevice::WrongData/WrongLength as the authenticator did not
+ // create the two key handles provided in the exclude list. At the third call,
// MockFidoDevice::NoErrorRegister will be invoked after registration.
::testing::InSequence s;